pub struct PooledExecutor { /* private fields */ }Expand description
Executor using a warm worker pool for maximum throughput.
Pre-spawns Python worker processes that stay alive between test runs, eliminating subprocess spawn overhead (200-300ms per batch).
Implementations
Sourceimpl PooledExecutor
impl PooledExecutor
Sourcepub async fn new(
python_path: PathBuf,
worker_count: usize,
working_dir: PathBuf,
) -> Result<Self>
pub async fn new( python_path: PathBuf, worker_count: usize, working_dir: PathBuf, ) -> Result<Self>
Create a new pooled executor.
Sourcepub fn update_duration(&mut self, node_id: &str, duration_ms: u64)
pub fn update_duration(&mut self, node_id: &str, duration_ms: u64)
Update duration history for a test.
Sourcepub fn scheduler_mut(&mut self) -> &mut TestScheduler
pub fn scheduler_mut(&mut self) -> &mut TestScheduler
Get the scheduler for external updates.