pub struct WorkerPool { /* private fields */ }Expand description
Pool of warm Python workers.
Implementations
Sourceimpl WorkerPool
impl WorkerPool
Sourcepub async fn new(
size: usize,
python_path: PathBuf,
working_dir: PathBuf,
) -> Result<Arc<Self>>
pub async fn new( size: usize, python_path: PathBuf, working_dir: PathBuf, ) -> Result<Arc<Self>>
Create a new worker pool with the specified size.
Sourcepub async fn execute_batch(&self, tests: Vec<String>) -> Vec<TestResult>
pub async fn execute_batch(&self, tests: Vec<String>) -> Vec<TestResult>
Execute a batch of tests on an available worker.
Sourcepub async fn execute_parallel(
self: &Arc<Self>,
batches: Vec<Vec<String>>,
) -> Vec<TestResult>
pub async fn execute_parallel( self: &Arc<Self>, batches: Vec<Vec<String>>, ) -> Vec<TestResult>
Execute multiple batches in parallel.
Sourcepub async fn available_count(&self) -> usize
pub async fn available_count(&self) -> usize
Get the current number of available workers.